@@ -70,7 +70,6 @@ def getSongs():
     return (names,namedict,durdict,osudict,timedict)
 
 
-
 def shuffle():
     random.shuffle(names)
     listwalker.clear()
@@ -216,8 +215,6 @@ def getSongList(a):
     listwalker = urwid.SimpleListWalker(content)
     return urwid.ListBox(listwalker)
 
-
-
 nowplayingtext = urwid.Text("osu-cplayer",'center')
 #default top bar text that will soon be replaced by the title of the playing song.
 def getNowPlaying():
@@ -396,6 +393,17 @@ def getFooter():
     footer = urwid.Pile([filterInput(),collectionInput()])
     return footer
 
+
+def inputFilter(inputs, raw_inputs):
+    #vim-like bindings
+    for n,k in enumerate(inputs):
+        if k=="j":
+            inputs[n]="down"
+        if k=="k":
+            inputs[n]="up"
+    return inputs
+
+
 def listener(key):
     global loopsong
     global filteredit
@@ -547,6 +555,7 @@ class BasicDbReader:
         Read a Datetime from the database-file
         """
         return self.read_long()
+
 class OsuDbReader(BasicDbReader):
     def __init__(self, file=None):
         super(OsuDbReader, self).__init__(file)
@@ -741,6 +750,8 @@ def main():
     listBox = getSongList(a)
     frame = urwid.Frame(listBox,header=getHeader(),footer=getFooter())
     #compile the frame with the header on top, listbox in the middle, and footer.
-    mainloop = urwid.MainLoop(frame,unhandled_input=listener,palette=palette)
+    mainloop = urwid.MainLoop(frame,input_filter=inputFilter, unhandled_input=listener,palette=palette)
     mainloop.run()
     player.terminate()
+
+main()
